==> ansible-10.0.0.tgz: lib/python3.11/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_firewall_ldbmonitor.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_firewall_ldbmonitor
short_description: Configure server load balancing health monitors.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.0.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    state:
        description: The directive to create, update or delete an object.
        type: str
        required: true
        choices:
          - present
          - absent
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    adom:
        description: The parameter (adom) in requested url.
        type: str
        required: true
    firewall_ldbmonitor:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            http-get:
                type: str
                description: Deprecated, please rename it to http_get. URL used to send a GET request to check the health of an HTTP server.
            http-match:
                type: str
                description: Deprecated, please rename it to http_match. String to match the value expected in response to an HTTP-GET request.
            http-max-redirects:
                type: int
                description: Deprecated, please rename it to http_max_redirects. The maximum number of HTTP redirects to be allowed
            interval:
                type: int
                description: Time between health checks
            name:
                type: str
                description: Monitor name.
                required: true
            port:
                type: int
                description: Service port used to perform the health check.
            retry:
                type: int
                description: Number health check attempts before the server is considered down
            timeout:
                type: int
                description: Time to wait to receive response to a health check from a server.
            type:
                type: str
                description: Select the Monitor type used by the health check monitor to check the health of the server
                choices:
                    - 'ping'
                    - 'tcp'
                    - 'http'
                    - 'passive-sip'
                    - 'https'
                    - 'dns'
            src-ip:
                type: str
                description: Deprecated, please rename it to src_ip. Source IP for ldb-monitor.
            dns-match-ip:
                type: str
                description: Deprecated, please rename it to dns_match_ip. Response IP expected from DNS server.
            dns-protocol:
                type: str
                description: Deprecated, please rename it to dns_protocol. Select the protocol used by the DNS health check monitor to check the health...
                choices:
                    - 'udp'
                    - 'tcp'
            dns-request-domain:
                type: str
                description: Deprecated, please rename it to dns_request_domain. Fully qualified domain name to resolve for the DNS probe.
'''

EXAMPLES = '''
- name: Example playbook
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Configure server load balancing health monitors.
      fortinet.fortimanager.fmgr_firewall_ldbmonitor:
        bypass_validation: false
        adom: ansible
        state: present
        firewall_ldbmonitor:
          name: "ansible-test"
          port: 1
          type: tcp # <value in [ping, tcp, http, ...]>

- name: Gathering fortimanager facts
  hosts: fortimanagers
  gather_facts: false
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Retrieve all the server load balancing health monitors
      fortinet.fortimanager.fmgr_fact:
        facts:
          selector: "firewall_ldbmonitor"
          params:
            adom: "ansible"
            ldb-monitor: "your_value"
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    jrpc_urls = [
        '/pm/config/adom/{adom}/obj/firewall/ldb-monitor',
        '/pm/config/global/obj/firewall/ldb-monitor'
    ]

    perobject_jrpc_urls = [
        '/pm/config/adom/{adom}/obj/firewall/ldb-monitor/{ldb-monitor}',
        '/pm/config/global/obj/firewall/ldb-monitor/{ldb-monitor}'
    ]

    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'adom': {'required': True, 'type': 'str'},
        'firewall_ldbmonitor': {
            'type': 'dict',
            'v_range': [['6.0.0', '']],
            'options': {
                'http-get': {'type': 'str'},
                'http-match': {'type': 'str'},
                'http-max-redirects': {'type': 'int'},
                'interval': {'type': 'int'},
                'name': {'required': True, 'type': 'str'},
                'port': {'type': 'int'},
                'retry': {'type': 'int'},
                'timeout': {'type': 'int'},
                'type': {'choices': ['ping', 'tcp', 'http', 'passive-sip', 'https', 'dns'], 'type': 'str'},
                'src-ip': {'v_range': [['6.4.0', '']], 'type': 'str'},
                'dns-match-ip': {'v_range': [['7.0.0', '']], 'type': 'str'},
                'dns-protocol': {'v_range': [['7.0.0', '']], 'choices': ['udp', 'tcp'], 'type': 'str'},
                'dns-request-domain': {'v_range': [['7.0.0', '']], 'type': 'str'}
            }

        }
    }

    module_option_spec = get_module_arg_spec('full crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_ldbmonitor'),
                           supports_check_mode=False)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    connection.set_option('access_token', module.params.get('access_token', None))
    connection.set_option('enable_log', module.params.get('enable_log', False))
    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_curd(argument_specs=module_arg_spec)

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()

==> ansible-11.4.0.tgz: lib/python3.12/site-packages/ansible_collections/fortinet/fortimanager/plugins/modules/fmgr_firewall_ldbmonitor.py <==
#!/usr/bin/python
from __future__ import absolute_import, division, print_function
# Copyright 2019-2024 Fortinet, Inc.
# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

__metaclass__ = type

ANSIBLE_METADATA = {'status': ['preview'],
                    'supported_by': 'community',
                    'metadata_version': '1.1'}

DOCUMENTATION = '''
---
module: fmgr_firewall_ldbmonitor
short_description: Configure server load balancing health monitors.
description:
    - This module is able to configure a FortiManager device.
    - Examples include all parameters and values which need to be adjusted to data sources before usage.

version_added: "2.0.0"
author:
    - Xinwei Du (@dux-fortinet)
    - Xing Li (@lix-fortinet)
    - Jie Xue (@JieX19)
    - Link Zheng (@chillancezen)
    - Frank Shen (@fshen01)
    - Hongbin Lu (@fgtdev-hblu)
notes:
    - Starting in version 2.4.0, all input arguments are named using the underscore naming convention (snake_case).
      Please change the arguments such as "var-name" to "var_name".
      Old argument names are still available yet you will receive deprecation warnings.
      You can ignore this warning by setting deprecation_warnings=False in ansible.cfg.
    - Running in workspace locking mode is supported in this FortiManager module, the top
      level parameters workspace_locking_adom and workspace_locking_timeout help do the work.
    - To create or update an object, use state present directive.
    - To delete an object, use state absent directive.
    - Normally, running one module can fail when a non-zero rc is returned. you can also override
      the conditions to fail or succeed with parameters rc_failed and rc_succeeded
options:
    access_token:
        description: The token to access FortiManager without using username and password.
        type: str
    bypass_validation:
        description: Only set to True when module schema diffs with FortiManager API structure, module continues to execute without validating parameters.
        type: bool
        default: false
    enable_log:
        description: Enable/Disable logging for task.
        type: bool
        default: false
    forticloud_access_token:
        description: Authenticate Ansible client with forticloud API access token.
        type: str
    proposed_method:
        description: The overridden method for the underlying Json RPC request.
        type: str
        choices:
          - update
          - set
          - add
    rc_succeeded:
        description: The rc codes list with which the conditions to succeed will be overriden.
        type: list
        elements: int
    rc_failed:
        description: The rc codes list with which the conditions to fail will be overriden.
        type: list
        elements: int
    state:
        description: The directive to create, update or delete an object.
        type: str
        required: true
        choices:
          - present
          - absent
    workspace_locking_adom:
        description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
        type: str
    workspace_locking_timeout:
        description: The maximum time in seconds to wait for other user to release the workspace lock.
        type: int
        default: 300
    adom:
        description: The parameter (adom) in requested url.
        type: str
        required: true
    firewall_ldbmonitor:
        description: The top level parameters set.
        required: false
        type: dict
        suboptions:
            http_get:
                aliases: ['http-get']
                type: str
                description: URL used to send a GET request to check the health of an HTTP server.
            http_match:
                aliases: ['http-match']
                type: str
                description: String to match the value expected in response to an HTTP-GET request.
            http_max_redirects:
                aliases: ['http-max-redirects']
                type: int
                description: The maximum number of HTTP redirects to be allowed
            interval:
                type: int
                description: Time between health checks
            name:
                type: str
                description: Monitor name.
                required: true
            port:
                type: int
                description: Service port used to perform the health check.
            retry:
                type: int
                description: Number health check attempts before the server is considered down
            timeout:
                type: int
                description: Time to wait to receive response to a health check from a server.
            type:
                type: str
                description: Select the Monitor type used by the health check monitor to check the health of the server
                choices:
                    - 'ping'
                    - 'tcp'
                    - 'http'
                    - 'passive-sip'
                    - 'https'
                    - 'dns'
            src_ip:
                aliases: ['src-ip']
                type: str
                description: Source IP for ldb-monitor.
            dns_match_ip:
                aliases: ['dns-match-ip']
                type: str
                description: Response IP expected from DNS server.
            dns_protocol:
                aliases: ['dns-protocol']
                type: str
                description: Select the protocol used by the DNS health check monitor to check the health of the server
                choices:
                    - 'udp'
                    - 'tcp'
            dns_request_domain:
                aliases: ['dns-request-domain']
                type: str
                description: Fully qualified domain name to resolve for the DNS probe.
'''

EXAMPLES = '''
- name: Example playbook
  hosts: fortimanagers
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Configure server load balancing health monitors.
      fortinet.fortimanager.fmgr_firewall_ldbmonitor:
        bypass_validation: false
        adom: ansible
        state: present
        firewall_ldbmonitor:
          name: "ansible-test"
          port: 1
          type: tcp # <value in [ping, tcp, http, ...]>

- name: Gathering fortimanager facts
  hosts: fortimanagers
  gather_facts: false
  connection: httpapi
  vars:
    ansible_httpapi_use_ssl: true
    ansible_httpapi_validate_certs: false
    ansible_httpapi_port: 443
  tasks:
    - name: Retrieve all the server load balancing health monitors
      fortinet.fortimanager.fmgr_fact:
        facts:
          selector: "firewall_ldbmonitor"
          params:
            adom: "ansible"
            ldb-monitor: "your_value"
'''

RETURN = '''
meta:
    description: The result of the request.
    type: dict
    returned: always
    contains:
        request_url:
            description: The full url requested.
            returned: always
            type: str
            sample: /sys/login/user
        response_code:
            description: The status of api request.
            returned: always
            type: int
            sample: 0
        response_data:
            description: The api response.
            type: list
            returned: always
        response_message:
            description: The descriptive message of the api response.
            type: str
            returned: always
            sample: OK.
        system_information:
            description: The information of the target system.
            type: dict
            returned: always
rc:
    description: The status the request.
    type: int
    returned: always
    sample: 0
version_check_warning:
    description: Warning if the parameters used in the playbook are not supported by the current FortiManager version.
    type: list
    returned: complex
'''
from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.connection import Connection
from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec


def main():
    urls_list = [
        '/pm/config/adom/{adom}/obj/firewall/ldb-monitor',
        '/pm/config/global/obj/firewall/ldb-monitor'
    ]
    url_params = ['adom']
    module_primary_key = 'name'
    module_arg_spec = {
        'adom': {'required': True, 'type': 'str'},
        'firewall_ldbmonitor': {
            'type': 'dict',
            'v_range': [['6.0.0', '']],
            'options': {
                'http-get': {'type': 'str'},
                'http-match': {'type': 'str'},
                'http-max-redirects': {'type': 'int'},
                'interval': {'type': 'int'},
                'name': {'required': True, 'type': 'str'},
                'port': {'type': 'int'},
                'retry': {'type': 'int'},
                'timeout': {'type': 'int'},
                'type': {'choices': ['ping', 'tcp', 'http', 'passive-sip', 'https', 'dns'], 'type': 'str'},
                'src-ip': {'v_range': [['6.4.0', '']], 'type': 'str'},
                'dns-match-ip': {'v_range': [['7.0.0', '']], 'type': 'str'},
                'dns-protocol': {'v_range': [['7.0.0', '']], 'choices': ['udp', 'tcp'], 'type': 'str'},
                'dns-request-domain': {'v_range': [['7.0.0', '']], 'type': 'str'}
            }
        }
    }

    module_option_spec = get_module_arg_spec('full crud')
    module_arg_spec.update(module_option_spec)
    params_validation_blob = []
    check_galaxy_version(module_arg_spec)
    module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_ldbmonitor'),
                           supports_check_mode=True)

    if not module._socket_path:
        module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
    connection = Connection(module._socket_path)
    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
                       module, connection, top_level_schema_name='data')
    fmgr.validate_parameters(params_validation_blob)
    fmgr.process_crud()

    module.exit_json(meta=module.params)


if __name__ == '__main__':
    main()
